diff --git a/core/misc/cspell/dictionary.txt b/core/misc/cspell/dictionary.txt
index 6f549cb648d36f2ef425af1c74170be897314437..b39295925c8b6051a7c672349fe642e33c1d8232 100644
--- a/core/misc/cspell/dictionary.txt
+++ b/core/misc/cspell/dictionary.txt
@@ -12,7 +12,6 @@ ahah
 aiufyfh
 ajaxcallback
 ajaxing
-akiko
 allwords
 alphadecimal
 alternatif
@@ -27,7 +26,6 @@ anyall
 applix
 archiver
 archivers
-arctor
 arrakis
 arrayx
 arrowrefresh
@@ -82,7 +80,6 @@ basefield
 basepath
 basestrings
 basetheme
-basicpage
 bazbaz
 beatle
 bebebe
@@ -113,9 +110,7 @@ bodyless
 bodyvalue
 boing
 bomofo
-bonacieux
 bovigo
-breezer
 brion
 brotli
 browserkit
@@ -217,14 +212,11 @@ createuser
 crema
 crossout
 crème
-cscript
 csrftoken
 cssidentifier
 csslintrc
 csstools
 ctags
-ctes
-ctund
 cucurbitaceae
 curle
 curlopt
@@ -246,7 +238,6 @@ dblog
 dbtng
 dburl
 dealerdirect
-deckard
 deconstructor
 defaultable
 defgroup
@@ -298,8 +289,6 @@ dotenv
 downcasting
 doxygen
 dragtable
-dramallama
-dramallamas
 drei
 drillable
 drivernumber
@@ -354,11 +343,9 @@ enregistrer
 entit
 entitytype
 entityviewedit
-eridani
 errmode
 errrf
 espagnol
-estraven
 etag
 eurozone
 evenodd
@@ -435,7 +422,6 @@ gloop
 gnumeric
 googleapis
 gotit
-grayskull
 greeking
 gripsmall
 groupable
@@ -485,7 +471,6 @@ imagetextalternative
 indexname
 inited
 inno
-insidekeyword
 instaclick
 instantiator
 interactable
@@ -649,9 +634,7 @@ mystarterkit
 nameofbin
 namespacing
 navs
-nbaz
 ndocs
-nearbykeyword
 necolas
 negotiatiors
 newcol
@@ -685,7 +668,6 @@ noquotes
 noschema
 nosniff
 nostart
-notag
 notexisting
 notnull
 notsimpletest
@@ -928,7 +910,6 @@ somecompany
 somelinks
 somemodule
 someschema
-somethinggeneric
 sortablejs
 sourceediting
 spacebar
@@ -974,7 +955,6 @@ subelements
 subform
 subform's
 subforms
-subjectkeyword
 subkey
 subkeys
 suboption
@@ -1022,7 +1002,6 @@ tablesort's
 tablesorts
 tabset
 tabwidth
-takeshita
 tappable
 tarz
 taskless
@@ -1204,7 +1183,6 @@ uploaders
 uploadprogress
 upscaling
 urandom
-urlalias
 usecase
 userid
 userinfo
@@ -1238,7 +1216,6 @@ wmlscript
 wordprocessingml
 wordsafe
 wordword
-workspaceswitcher
 writeln
 wwwrun
 xbap
diff --git a/core/modules/block_content/tests/src/Functional/Rest/BlockContentResourceTestBase.php b/core/modules/block_content/tests/src/Functional/Rest/BlockContentResourceTestBase.php
index eb4c0c491f923b33988ec838af3a74a58428866e..5fe3b7ffaee6a63a48a748984492af84126c58c4 100644
--- a/core/modules/block_content/tests/src/Functional/Rest/BlockContentResourceTestBase.php
+++ b/core/modules/block_content/tests/src/Functional/Rest/BlockContentResourceTestBase.php
@@ -184,7 +184,7 @@ protected function getNormalizedPostEntity() {
       ],
       'info' => [
         [
-          'value' => 'Dramallama',
+          'value' => 'Drama llama',
         ],
       ],
     ];
diff --git a/core/modules/comment/tests/src/Functional/Rest/CommentResourceTestBase.php b/core/modules/comment/tests/src/Functional/Rest/CommentResourceTestBase.php
index 8a61e2b9be09f4d95fbf7eaa1dc26a33e773ef99..ac1a1b7ffb6b037a979674bb61b6aba464a2b48a 100644
--- a/core/modules/comment/tests/src/Functional/Rest/CommentResourceTestBase.php
+++ b/core/modules/comment/tests/src/Functional/Rest/CommentResourceTestBase.php
@@ -241,7 +241,7 @@ protected function getNormalizedPostEntity() {
       ],
       'subject' => [
         [
-          'value' => 'Dramallama',
+          'value' => 'Drama llama',
         ],
       ],
       'comment_body' => [
diff --git a/core/modules/contact/tests/src/Functional/Rest/MessageResourceTestBase.php b/core/modules/contact/tests/src/Functional/Rest/MessageResourceTestBase.php
index cf37c75cc0525d761078837d2352359ad3e5ed6e..3e204cc4bdd5b6158623030f71c5bbdfc8222aaf 100644
--- a/core/modules/contact/tests/src/Functional/Rest/MessageResourceTestBase.php
+++ b/core/modules/contact/tests/src/Functional/Rest/MessageResourceTestBase.php
@@ -74,7 +74,7 @@ protected function getNormalizedPostEntity() {
     return [
       'subject' => [
         [
-          'value' => 'Dramallama',
+          'value' => 'Drama llama',
         ],
       ],
       'contact_form' => [
diff --git a/core/modules/field_ui/tests/src/Functional/ManageDisplayTest.php b/core/modules/field_ui/tests/src/Functional/ManageDisplayTest.php
index 910b33f041b3a10d796634520b847b7e822e9a0b..6da294625c9e6e20f7caf0a56e11a2ed369381c7 100644
--- a/core/modules/field_ui/tests/src/Functional/ManageDisplayTest.php
+++ b/core/modules/field_ui/tests/src/Functional/ManageDisplayTest.php
@@ -246,12 +246,12 @@ public function testViewModeLocalTasksOrder() {
     $this->assertOrderInPage(['RSS', 'Teaser']);
 
     $edit = [
-      'label' => 'Breezer',
+      'label' => 'Breezier',
     ];
     $this->drupalGet('admin/structure/display-modes/view/manage/node.teaser');
     $this->submitForm($edit, 'Save');
 
-    $this->assertOrderInPage(['Breezer', 'RSS']);
+    $this->assertOrderInPage(['Breezier', 'RSS']);
   }
 
   /**
diff --git a/core/modules/image/tests/src/Functional/ImageOnTranslatedEntityTest.php b/core/modules/image/tests/src/Functional/ImageOnTranslatedEntityTest.php
index 19538f36aea33dbe2da0c22a001cc329211866f0..5c72b36900a5abd44198ead2934181af35eeee13 100644
--- a/core/modules/image/tests/src/Functional/ImageOnTranslatedEntityTest.php
+++ b/core/modules/image/tests/src/Functional/ImageOnTranslatedEntityTest.php
@@ -46,11 +46,11 @@ protected function setUp(): void {
     // Create the "Basic page" node type.
     // @todo Remove the disabling of new revision creation in
     //   https://www.drupal.org/node/1239558.
-    $this->drupalCreateContentType(['type' => 'basicpage', 'name' => 'Basic page', 'new_revision' => FALSE]);
+    $this->drupalCreateContentType(['type' => 'basic_page', 'name' => 'Basic page', 'new_revision' => FALSE]);
 
     // Create an image field on the "Basic page" node type.
     $this->fieldName = $this->randomMachineName();
-    $this->createImageField($this->fieldName, 'basicpage', [], ['title_field' => 1]);
+    $this->createImageField($this->fieldName, 'basic_page', [], ['title_field' => 1]);
 
     // Create and log in user.
     $permissions = [
@@ -60,10 +60,10 @@ protected function setUp(): void {
       'administer languages',
       'administer node fields',
       'create content translations',
-      'create basicpage content',
-      'edit any basicpage content',
+      'create basic_page content',
+      'edit any basic_page content',
       'translate any entity',
-      'delete any basicpage content',
+      'delete any basic_page content',
     ];
     $admin_user = $this->drupalCreateUser($permissions);
     $this->drupalLogin($admin_user);
@@ -87,24 +87,24 @@ public function testSyncedImages() {
     // Enable translation for "Basic page" nodes.
     $edit = [
       'entity_types[node]' => 1,
-      'settings[node][basicpage][translatable]' => 1,
-      "settings[node][basicpage][fields][$this->fieldName]" => 1,
-      "settings[node][basicpage][columns][$this->fieldName][file]" => 1,
+      'settings[node][basic_page][translatable]' => 1,
+      "settings[node][basic_page][fields][$this->fieldName]" => 1,
+      "settings[node][basic_page][columns][$this->fieldName][file]" => 1,
       // Explicitly disable alt and title since the javascript disables the
       // checkboxes on the form.
-      "settings[node][basicpage][columns][$this->fieldName][alt]" => FALSE,
-      "settings[node][basicpage][columns][$this->fieldName][title]" => FALSE,
+      "settings[node][basic_page][columns][$this->fieldName][alt]" => FALSE,
+      "settings[node][basic_page][columns][$this->fieldName][title]" => FALSE,
     ];
     $this->drupalGet('admin/config/regional/content-language');
     $this->submitForm($edit, 'Save configuration');
 
     // Verify that the image field on the "Basic basic" node type is
     // translatable.
-    $definitions = \Drupal::service('entity_field.manager')->getFieldDefinitions('node', 'basicpage');
+    $definitions = \Drupal::service('entity_field.manager')->getFieldDefinitions('node', 'basic_page');
     $this->assertTrue($definitions[$this->fieldName]->isTranslatable(), 'Node image field is translatable.');
 
     // Create a default language node.
-    $default_language_node = $this->drupalCreateNode(['type' => 'basicpage', 'title' => 'Lost in translation']);
+    $default_language_node = $this->drupalCreateNode(['type' => 'basic_page', 'title' => 'Lost in translation']);
 
     // Edit the node to upload a file.
     $edit = [];
@@ -155,11 +155,11 @@ public function testSyncedImages() {
 
     // Upload a different file.
     $edit = [];
-    $edit['title[0][value]'] = 'Akiko Takeshita';
+    $edit['title[0][value]'] = 'Ada Lovelace';
     $name = 'files[' . $this->fieldName . '_0]';
     $edit[$name] = \Drupal::service('file_system')->realpath($this->drupalGetTestFiles('image')[2]->uri);
     $this->submitForm($edit, 'Save (this translation)');
-    $edit = [$this->fieldName . '[0][alt]' => 'Akiko Takeshita image', $this->fieldName . '[0][title]' => 'Akiko Takeshita image title'];
+    $edit = [$this->fieldName . '[0][alt]' => 'Ada Lovelace image', $this->fieldName . '[0][title]' => 'Ada Lovelace image title'];
     $this->submitForm($edit, 'Save (this translation)');
     $third_fid = $this->getLastFileId();
 
@@ -174,8 +174,8 @@ public function testSyncedImages() {
     $this->assertSession()->responseContains('title="Lost in translation image title"');
     // View the translated node.
     $this->drupalGet('nl/node/' . $default_language_node->id());
-    $this->assertSession()->responseContains('alt="Akiko Takeshita image"');
-    $this->assertSession()->responseContains('title="Akiko Takeshita image title"');
+    $this->assertSession()->responseContains('alt="Ada Lovelace image"');
+    $this->assertSession()->responseContains('title="Ada Lovelace image title"');
 
     // Ensure the file status of the second file is permanent.
     $file = File::load($second_fid);
diff --git a/core/modules/jsonapi/tests/src/Functional/BlockContentTest.php b/core/modules/jsonapi/tests/src/Functional/BlockContentTest.php
index 2e5308890e10aec4a773f08f19b764ea7bd12042..2132ad06920b3a1bb7d6781334118f5b724130a4 100644
--- a/core/modules/jsonapi/tests/src/Functional/BlockContentTest.php
+++ b/core/modules/jsonapi/tests/src/Functional/BlockContentTest.php
@@ -207,7 +207,7 @@ protected function getPostDocument() {
       'data' => [
         'type' => 'block_content--basic',
         'attributes' => [
-          'info' => 'Dramallama',
+          'info' => 'Drama llama',
         ],
       ],
     ];
diff --git a/core/modules/jsonapi/tests/src/Functional/CommentTest.php b/core/modules/jsonapi/tests/src/Functional/CommentTest.php
index a291e53982574ebdeff6d0e0867c104cade7f74f..3f03791ae7159b51e7967ccf77516c1777fbbac0 100644
--- a/core/modules/jsonapi/tests/src/Functional/CommentTest.php
+++ b/core/modules/jsonapi/tests/src/Functional/CommentTest.php
@@ -245,7 +245,7 @@ protected function getPostDocument() {
         'attributes' => [
           'entity_type' => 'entity_test',
           'field_name' => 'comment',
-          'subject' => 'Dramallama',
+          'subject' => 'Drama llama',
           'comment_body' => [
             'value' => 'Llamas are awesome.',
             'format' => 'plain_text',
diff --git a/core/modules/jsonapi/tests/src/Functional/EntityTestComputedFieldTest.php b/core/modules/jsonapi/tests/src/Functional/EntityTestComputedFieldTest.php
index 8cc53d049a9c582fefbdfee42571c11f5f6d389d..0f22c1187dd40126b0a5ac7c4516c80f73c73122 100644
--- a/core/modules/jsonapi/tests/src/Functional/EntityTestComputedFieldTest.php
+++ b/core/modules/jsonapi/tests/src/Functional/EntityTestComputedFieldTest.php
@@ -148,7 +148,7 @@ protected function getPostDocument() {
       'data' => [
         'type' => 'entity_test_computed_field--entity_test_computed_field',
         'attributes' => [
-          'name' => 'Dramallama',
+          'name' => 'Drama llama',
         ],
       ],
     ];
diff --git a/core/modules/jsonapi/tests/src/Functional/EntityTestMapFieldTest.php b/core/modules/jsonapi/tests/src/Functional/EntityTestMapFieldTest.php
index acb1e7f12229e2e68939fcb48c46f625c3f920ca..1bb12240520dbc83f89ed414ed6e08592aa57876 100644
--- a/core/modules/jsonapi/tests/src/Functional/EntityTestMapFieldTest.php
+++ b/core/modules/jsonapi/tests/src/Functional/EntityTestMapFieldTest.php
@@ -142,7 +142,7 @@ protected function getPostDocument() {
       'data' => [
         'type' => 'entity_test_map_field--entity_test_map_field',
         'attributes' => [
-          'name' => 'Dramallama',
+          'name' => 'Drama llama',
           'data' => static::$mapValue,
         ],
       ],
diff --git a/core/modules/jsonapi/tests/src/Functional/EntityTestTest.php b/core/modules/jsonapi/tests/src/Functional/EntityTestTest.php
index 09d798f8432ccc1a18a1ed8ebae2481e44f95418..6e59823b7aa9639bef7921530e5c02fbc57232a8 100644
--- a/core/modules/jsonapi/tests/src/Functional/EntityTestTest.php
+++ b/core/modules/jsonapi/tests/src/Functional/EntityTestTest.php
@@ -154,7 +154,7 @@ protected function getPostDocument() {
       'data' => [
         'type' => 'entity_test--entity_test',
         'attributes' => [
-          'name' => 'Dramallama',
+          'name' => 'Drama llama',
         ],
       ],
     ];
diff --git a/core/modules/jsonapi/tests/src/Functional/FileUploadTest.php b/core/modules/jsonapi/tests/src/Functional/FileUploadTest.php
index 6b48a7060cc9515e042845bc1bb27538954e53dd..6dda61fd5bb89cafc09eab25234e19e9a8ecb8fc 100644
--- a/core/modules/jsonapi/tests/src/Functional/FileUploadTest.php
+++ b/core/modules/jsonapi/tests/src/Functional/FileUploadTest.php
@@ -371,7 +371,7 @@ protected function getPostDocument() {
       'data' => [
         'type' => 'entity_test--entity_test',
         'attributes' => [
-          'name' => 'Dramallama',
+          'name' => 'Drama llama',
         ],
         'relationships' => [
           'field_rest_file_test' => [
diff --git a/core/modules/jsonapi/tests/src/Functional/MediaTest.php b/core/modules/jsonapi/tests/src/Functional/MediaTest.php
index d169934048f1f3e3790e12a95ac863aeb51acbaf..58e027af822b5702a121c11238a55fa4c03e56e6 100644
--- a/core/modules/jsonapi/tests/src/Functional/MediaTest.php
+++ b/core/modules/jsonapi/tests/src/Functional/MediaTest.php
@@ -298,7 +298,7 @@ protected function getPostDocument() {
       'data' => [
         'type' => 'media--camelids',
         'attributes' => [
-          'name' => 'Dramallama',
+          'name' => 'Drama llama',
         ],
         'relationships' => [
           'field_media_file' => [
diff --git a/core/modules/jsonapi/tests/src/Functional/MenuLinkContentTest.php b/core/modules/jsonapi/tests/src/Functional/MenuLinkContentTest.php
index 617d454e0ea5430249744b470444fd2aee56df72..efc47df28b41790f99c33598c9dda98cfe70d16c 100644
--- a/core/modules/jsonapi/tests/src/Functional/MenuLinkContentTest.php
+++ b/core/modules/jsonapi/tests/src/Functional/MenuLinkContentTest.php
@@ -160,7 +160,7 @@ protected function getPostDocument() {
       'data' => [
         'type' => 'menu_link_content--menu_link_content',
         'attributes' => [
-          'title' => 'Dramallama',
+          'title' => 'Drama llama',
           'link' => [
             'uri' => 'http://www.urbandictionary.com/define.php?term=drama%20llama',
           ],
diff --git a/core/modules/jsonapi/tests/src/Functional/MessageTest.php b/core/modules/jsonapi/tests/src/Functional/MessageTest.php
index e8e6f03527bb4f63c8089f611409093019ad44c2..025433589d52c92522d5447f051e9f77eea5d857 100644
--- a/core/modules/jsonapi/tests/src/Functional/MessageTest.php
+++ b/core/modules/jsonapi/tests/src/Functional/MessageTest.php
@@ -99,7 +99,7 @@ protected function getPostDocument() {
       'data' => [
         'type' => 'contact_message--camelids',
         'attributes' => [
-          'subject' => 'Dramallama',
+          'subject' => 'Drama llama',
           'message' => 'http://www.urbandictionary.com/define.php?term=drama%20llama',
         ],
       ],
diff --git a/core/modules/jsonapi/tests/src/Functional/NodeTest.php b/core/modules/jsonapi/tests/src/Functional/NodeTest.php
index 376d4a7bc29bbf1a944adfc1468b7cc2e7cb2e57..ca9a4d9a6638a147e5f96ffae993fe2a4cf80769 100644
--- a/core/modules/jsonapi/tests/src/Functional/NodeTest.php
+++ b/core/modules/jsonapi/tests/src/Functional/NodeTest.php
@@ -252,7 +252,7 @@ protected function getPostDocument() {
       'data' => [
         'type' => 'node--camelids',
         'attributes' => [
-          'title' => 'Dramallama',
+          'title' => 'Drama llama',
         ],
       ],
     ];
diff --git a/core/modules/jsonapi/tests/src/Functional/TermTest.php b/core/modules/jsonapi/tests/src/Functional/TermTest.php
index 77acd006294211d9c0cdde006b9a12b137088f18..e438d1f1aa4efc9a980cda58ff857b8100289802 100644
--- a/core/modules/jsonapi/tests/src/Functional/TermTest.php
+++ b/core/modules/jsonapi/tests/src/Functional/TermTest.php
@@ -350,9 +350,9 @@ protected function getPostDocument() {
       'data' => [
         'type' => 'taxonomy_term--camelids',
         'attributes' => [
-          'name' => 'Dramallama',
+          'name' => 'Drama llama',
           'description' => [
-            'value' => 'Dramallamas are the coolest camelids.',
+            'value' => 'Drama llamas are the coolest camelids.',
             'format' => NULL,
           ],
         ],
diff --git a/core/modules/jsonapi/tests/src/Functional/UserTest.php b/core/modules/jsonapi/tests/src/Functional/UserTest.php
index 56090392619ea15f13dd468fd5e33fe6b6188c3f..e1672cb748d766bed2440f1b08eefddb38466ba0 100644
--- a/core/modules/jsonapi/tests/src/Functional/UserTest.php
+++ b/core/modules/jsonapi/tests/src/Functional/UserTest.php
@@ -187,7 +187,7 @@ protected function getPostDocument() {
       'data' => [
         'type' => 'user--user',
         'attributes' => [
-          'name' => 'Dramallama',
+          'name' => 'Drama llama',
         ],
       ],
     ];
diff --git a/core/modules/language/tests/src/Kernel/EntityDefaultLanguageTest.php b/core/modules/language/tests/src/Kernel/EntityDefaultLanguageTest.php
index 513045d64b3b88da8e65c2984f33b004e179ac82..dd56b4bbd9e284cda3c6406c28c1cfb122b81913 100644
--- a/core/modules/language/tests/src/Kernel/EntityDefaultLanguageTest.php
+++ b/core/modules/language/tests/src/Kernel/EntityDefaultLanguageTest.php
@@ -43,9 +43,9 @@ protected function setUp(): void {
     $language->save();
 
     // Create a new content type which has Undefined language by default.
-    $this->createContentType('ctund', LanguageInterface::LANGCODE_NOT_SPECIFIED);
+    $this->createContentType('content_und', LanguageInterface::LANGCODE_NOT_SPECIFIED);
     // Create a new content type which has Spanish language by default.
-    $this->createContentType('ctes', 'es');
+    $this->createContentType('content_es', 'es');
   }
 
   /**
@@ -55,23 +55,23 @@ public function testEntityTranslationDefaultLanguageViaCode() {
     // With language module activated, and a content type that is configured to
     // have no language by default, a new node of this content type will have
     // "und" language code when language is not specified.
-    $node = $this->createNode('ctund');
+    $node = $this->createNode('content_und');
     $this->assertEquals(LanguageInterface::LANGCODE_NOT_SPECIFIED, $node->langcode->value);
     // With language module activated, and a content type that is configured to
     // have no language by default, a new node of this content type will have
     // "es" language code when language is specified as "es".
-    $node = $this->createNode('ctund', 'es');
+    $node = $this->createNode('content_und', 'es');
     $this->assertEquals('es', $node->langcode->value);
 
     // With language module activated, and a content type that is configured to
     // have language "es" by default, a new node of this content type will have
     // "es" language code when language is not specified.
-    $node = $this->createNode('ctes');
+    $node = $this->createNode('content_es');
     $this->assertEquals('es', $node->langcode->value);
     // With language module activated, and a content type that is configured to
     // have language "es" by default, a new node of this content type will have
     // "en" language code when language "en" is specified.
-    $node = $this->createNode('ctes', 'en');
+    $node = $this->createNode('content_es', 'en');
     $this->assertEquals('en', $node->langcode->value);
 
     // Disable language module.
@@ -80,23 +80,23 @@ public function testEntityTranslationDefaultLanguageViaCode() {
     // With language module disabled, and a content type that is configured to
     // have no language specified by default, a new node of this content type
     // will have site's default language code when language is not specified.
-    $node = $this->createNode('ctund');
+    $node = $this->createNode('content_und');
     $this->assertEquals('en', $node->langcode->value);
     // With language module disabled, and a content type that is configured to
     // have no language specified by default, a new node of this type will have
     // "es" language code when language "es" is specified.
-    $node = $this->createNode('ctund', 'es');
+    $node = $this->createNode('content_und', 'es');
     $this->assertEquals('es', $node->langcode->value);
 
     // With language module disabled, and a content type that is configured to
     // have language "es" by default, a new node of this type will have site's
     // default language code when language is not specified.
-    $node = $this->createNode('ctes');
+    $node = $this->createNode('content_es');
     $this->assertEquals('en', $node->langcode->value);
     // With language module disabled, and a content type that is configured to
     // have language "es" by default, a new node of this type will have "en"
     // language code when language "en" is specified.
-    $node = $this->createNode('ctes', 'en');
+    $node = $this->createNode('content_es', 'en');
     $this->assertEquals('en', $node->langcode->value);
   }
 
diff --git a/core/modules/media/tests/fixtures/oembed/rich_twitter.json b/core/modules/media/tests/fixtures/oembed/rich_twitter.json
index 17bbe1f21e560ada329faadef5fef40b900a4966..fd0dcc54d93d426b9222367e18e373e8eaed20ff 100644
--- a/core/modules/media/tests/fixtures/oembed/rich_twitter.json
+++ b/core/modules/media/tests/fixtures/oembed/rich_twitter.json
@@ -2,7 +2,7 @@
   "url": "https:\/\/twitter.com\/drupaldevdays\/status\/935643039741202432",
   "author_name": "Drupal Dev Days",
   "author_url": "https:\/\/twitter.com\/drupaldevdays",
-  "html": "<h1>By the power of Grayskull, Twitter works!</h1>",
+  "html": "<h1>Twitter works!</h1>",
   "width": 550,
   "height": null,
   "type": "rich",
diff --git a/core/modules/media/tests/fixtures/oembed/video_collegehumor.xml b/core/modules/media/tests/fixtures/oembed/video_collegehumor.xml
index 0894cafcf97e34f6789f0a6a6f63ddd426146bed..6a622ee765ed7e6d6a0f8327dbaa3166c52a43f5 100644
--- a/core/modules/media/tests/fixtures/oembed/video_collegehumor.xml
+++ b/core/modules/media/tests/fixtures/oembed/video_collegehumor.xml
@@ -10,7 +10,7 @@
   <provider_url>http://www.collegehumor.com</provider_url>
   <width>610</width>
   <height>343</height>
-  <html><h1>By the power of Grayskull, CollegeHumor works!</h1>
+  <html><h1>CollegeHumor works!</h1>
   </html>
   <!-- The thumbnail URL does not contain a file extension, so we use
   this to test the oEmbed source plugin's thumbnail handling;
diff --git a/core/modules/media/tests/fixtures/oembed/video_vimeo-no-title.json b/core/modules/media/tests/fixtures/oembed/video_vimeo-no-title.json
index ac1867a5fe1746b4a549f411b4ab3e7dbc48e869..e68e1235e9e8d45002d723056470cc4853cba8ce 100644
--- a/core/modules/media/tests/fixtures/oembed/video_vimeo-no-title.json
+++ b/core/modules/media/tests/fixtures/oembed/video_vimeo-no-title.json
@@ -6,7 +6,7 @@
   "title": "",
   "author_name": "Tendenci - The Open Source AMS",
   "author_url": "https:\/\/vimeo.com\/schipul",
-  "html": "<iframe width=\"480\">By the power of Grayskull, Vimeo works!</iframe>",
+  "html": "<iframe width=\"480\">Vimeo works!</iframe>",
   "width": 480,
   "height": 360,
   "description": "Special thanks to Tendenci, formerly Schipul for sponsoring this video with training, equipment and time. The open source way. All creative however was self directed by the individuals - A. Hughes (www.schipul.com\/ahughes) featuring QCait (www.schipul.com\/qcait) - Hands On Drupal\n\nDrupal is a free software package that allows an individual or a community of users to easily publish, manage and organize a wide variety of content on a website.\n\nNeed a little Drupal help or just want to geek out with us?  Visit our www.schipul.com\/drupal for more info - we'd love to connect!\n\nGo here for Drupal Common Terms and Suggested Modules : http:\/\/schipul.com\/en\/helpfiles\/v\/229",
diff --git a/core/modules/media/tests/fixtures/oembed/video_vimeo.json b/core/modules/media/tests/fixtures/oembed/video_vimeo.json
index 9a0c5092e4ef402b848d7e295f84c2d876fb9c95..8b9689e146f986ffe993db47ee25695a869a3bbb 100644
--- a/core/modules/media/tests/fixtures/oembed/video_vimeo.json
+++ b/core/modules/media/tests/fixtures/oembed/video_vimeo.json
@@ -6,7 +6,7 @@
   "title": "Drupal Rap Video - Schipulcon09",
   "author_name": "Tendenci - The Open Source AMS",
   "author_url": "https:\/\/vimeo.com\/schipul",
-  "html": "<iframe width=\"480\">By the power of Grayskull, Vimeo works!</iframe>",
+  "html": "<iframe width=\"480\">Vimeo works!</iframe>",
   "width": 480,
   "height": 360,
   "description": "Special thanks to Tendenci, formerly Schipul for sponsoring this video with training, equipment and time. The open source way. All creative however was self directed by the individuals - A. Hughes (www.schipul.com\/ahughes) featuring QCait (www.schipul.com\/qcait) - Hands On Drupal\n\nDrupal is a free software package that allows an individual or a community of users to easily publish, manage and organize a wide variety of content on a website.\n\nNeed a little Drupal help or just want to geek out with us?  Visit our www.schipul.com\/drupal for more info - we'd love to connect!\n\nGo here for Drupal Common Terms and Suggested Modules : http:\/\/schipul.com\/en\/helpfiles\/v\/229",
diff --git a/core/modules/media/tests/fixtures/oembed/video_youtube.json b/core/modules/media/tests/fixtures/oembed/video_youtube.json
index 9dd275c9e5a1e94424f9394b39524df3988a3054..6886aaa0fcea860a41a6a0bf9578e18808d269f3 100644
--- a/core/modules/media/tests/fixtures/oembed/video_youtube.json
+++ b/core/modules/media/tests/fixtures/oembed/video_youtube.json
@@ -6,7 +6,7 @@
   "title": "Everyday I'm Drupalin' Drupal Rap (Rick Ross - Hustlin)",
   "author_name": "Mirakolous",
   "author_url": "https:\/\/www.youtube.com\/user\/Mirakolous",
-  "html": "<h1>By the power of Grayskull, YouTube works!</h1>",
+  "html": "<h1>YouTube works!</h1>",
   "width": 480,
   "height": 270,
   "thumbnail_url": "internal:\/core\/misc\/druplicon.png",
diff --git a/core/modules/media/tests/src/Functional/Rest/MediaResourceTestBase.php b/core/modules/media/tests/src/Functional/Rest/MediaResourceTestBase.php
index 7de1123781f981b9bf8558aec96caaa58092f4ff..fbb4b4f04c3ebb61f569f422dfc6f142b0e881e6 100644
--- a/core/modules/media/tests/src/Functional/Rest/MediaResourceTestBase.php
+++ b/core/modules/media/tests/src/Functional/Rest/MediaResourceTestBase.php
@@ -266,7 +266,7 @@ protected function getNormalizedPostEntity() {
       ],
       'name' => [
         [
-          'value' => 'Dramallama',
+          'value' => 'Drama llama',
         ],
       ],
       'field_media_file' => [
diff --git a/core/modules/media/tests/src/FunctionalJavascript/MediaSourceImageTest.php b/core/modules/media/tests/src/FunctionalJavascript/MediaSourceImageTest.php
index 5e79060fc3e283810b88b3c8735f4c7efa2f45b8..590fd055c1c061e44fdedc8cd5291aeecfb0d280 100644
--- a/core/modules/media/tests/src/FunctionalJavascript/MediaSourceImageTest.php
+++ b/core/modules/media/tests/src/FunctionalJavascript/MediaSourceImageTest.php
@@ -109,13 +109,13 @@ public function testMediaImageSource() {
     // Instead, add a warning on the 'Status report' page.
     ImageStyle::load('large')->delete();
     $this->drupalGet('admin/structure/media/add');
-    $page->fillField('label', 'Madame Bonacieux');
-    $this->assertNotEmpty($assert_session->waitForText('Machine name: madame_bonacieux'));
+    $page->fillField('label', 'Ada Lovelace');
+    $this->assertNotEmpty($assert_session->waitForText('Machine name: ada_lovelace'));
     $page->selectFieldOption('source', 'image');
     // Wait for the form to complete with AJAX.
     $this->assertNotEmpty($assert_session->waitForText('Field mapping'));
     $page->pressButton('Save');
-    $this->assertViewDisplayConfigured('madame_bonacieux');
+    $this->assertViewDisplayConfigured('ada_lovelace');
 
     // Create user without the 'administer media display' permission.
     $this->drupalLogin($this->drupalCreateUser([
@@ -132,9 +132,9 @@ public function testMediaImageSource() {
     $this->drupalGet('/admin/reports/status');
     // The image style warning should not include an action link when the
     // current user lacks the permission 'administer media display'.
-    $assert_session->pageTextContains('The default display for the Madame Bonacieux media type is not currently using an image style on the Image field. Not using an image style can lead to much larger file downloads.');
+    $assert_session->pageTextContains('The default display for the Ada Lovelace media type is not currently using an image style on the Image field. Not using an image style can lead to much larger file downloads.');
     $assert_session->linkNotExists('add an image style to the Image field');
-    $assert_session->linkByHrefNotExists('/admin/structure/media/manage/madame_bonacieux/display');
+    $assert_session->linkByHrefNotExists('/admin/structure/media/manage/ada_lovelace/display');
 
     // The image style warning should include an action link when the current
     // user has the permission 'administer media display'.
@@ -142,17 +142,17 @@ public function testMediaImageSource() {
       ->grantPermission('administer media display')
       ->save();
     $this->drupalGet('/admin/reports/status');
-    $assert_session->pageTextContains('The default display for the Madame Bonacieux media type is not currently using an image style on the Image field. Not using an image style can lead to much larger file downloads. If you would like to change this, add an image style to the Image field.');
+    $assert_session->pageTextContains('The default display for the Ada Lovelace media type is not currently using an image style on the Image field. Not using an image style can lead to much larger file downloads. If you would like to change this, add an image style to the Image field.');
     $assert_session->linkExists('add an image style to the Image field');
-    $assert_session->linkByHrefExists('/admin/structure/media/manage/madame_bonacieux/display');
+    $assert_session->linkByHrefExists('/admin/structure/media/manage/ada_lovelace/display');
 
     // The image style warning should not include an action link when the
     // Field UI module is uninstalled.
     $this->container->get('module_installer')->uninstall(['field_ui']);
     $this->drupalGet('/admin/reports/status');
-    $assert_session->pageTextContains('The default display for the Madame Bonacieux media type is not currently using an image style on the Image field. Not using an image style can lead to much larger file downloads.');
+    $assert_session->pageTextContains('The default display for the Ada Lovelace media type is not currently using an image style on the Image field. Not using an image style can lead to much larger file downloads.');
     $assert_session->linkNotExists('add an image style to the Image field');
-    $assert_session->linkByHrefNotExists('/admin/structure/media/manage/madame_bonacieux/display');
+    $assert_session->linkByHrefNotExists('/admin/structure/media/manage/ada_lovelace/display');
   }
 
   /**
diff --git a/core/modules/media/tests/src/FunctionalJavascript/MediaSourceOEmbedVideoTest.php b/core/modules/media/tests/src/FunctionalJavascript/MediaSourceOEmbedVideoTest.php
index 62b7500be83356bde64cbbdf49d4a5b221bb3d5b..7133a1ea08344321d29515e6f743929e7d0a540d 100644
--- a/core/modules/media/tests/src/FunctionalJavascript/MediaSourceOEmbedVideoTest.php
+++ b/core/modules/media/tests/src/FunctionalJavascript/MediaSourceOEmbedVideoTest.php
@@ -194,20 +194,20 @@ public function testMediaOEmbedVideoSource() {
     // Without a hash should be denied.
     $no_hash_query = array_diff_key($query, ['hash' => '']);
     $this->drupalGet('media/oembed', ['query' => $no_hash_query]);
-    $assert_session->pageTextNotContains('By the power of Grayskull, Vimeo works!');
+    $assert_session->pageTextNotContains('Vimeo works!');
     $assert_session->pageTextContains('Client error');
 
     // A correct query should be allowed because the anonymous role has the
     // 'view media' permission.
     $this->drupalGet('media/oembed', ['query' => $query]);
-    $assert_session->pageTextContains('By the power of Grayskull, Vimeo works!');
+    $assert_session->pageTextContains('Vimeo works!');
 
     // Remove the 'view media' permission to test that this restricts access.
     $role = Role::load(AccountInterface::ANONYMOUS_ROLE);
     $role->revokePermission('view media');
     $role->save();
     $this->drupalGet('media/oembed', ['query' => $query]);
-    $assert_session->pageTextNotContains('By the power of Grayskull, Vimeo works!');
+    $assert_session->pageTextNotContains('Vimeo works!');
     $assert_session->pageTextContains('Access denied');
   }
 
diff --git a/core/modules/menu_link_content/tests/src/Functional/Rest/MenuLinkContentResourceTestBase.php b/core/modules/menu_link_content/tests/src/Functional/Rest/MenuLinkContentResourceTestBase.php
index 448dfd2394f0c5176d46b4840ab0f9ad2c7a28af..d801f12c99836b9c2c956538334bf2a863cd7137 100644
--- a/core/modules/menu_link_content/tests/src/Functional/Rest/MenuLinkContentResourceTestBase.php
+++ b/core/modules/menu_link_content/tests/src/Functional/Rest/MenuLinkContentResourceTestBase.php
@@ -80,7 +80,7 @@ protected function getNormalizedPostEntity() {
     return [
       'title' => [
         [
-          'value' => 'Dramallama',
+          'value' => 'Drama llama',
         ],
       ],
       'link' => [
diff --git a/core/modules/migrate/tests/src/Unit/Exception/RequirementsExceptionTest.php b/core/modules/migrate/tests/src/Unit/Exception/RequirementsExceptionTest.php
index 47275a0ba4832f258b6cd0abe79c6f4b51ba158b..0a61d2821f37f6656943db05ecbb9b27ae995f96 100644
--- a/core/modules/migrate/tests/src/Unit/Exception/RequirementsExceptionTest.php
+++ b/core/modules/migrate/tests/src/Unit/Exception/RequirementsExceptionTest.php
@@ -11,7 +11,7 @@
  */
 class RequirementsExceptionTest extends UnitTestCase {
 
-  protected const MISSING_REQUIREMENTS = ['random_jackson_pivot', '51_Eridani_b'];
+  protected const MISSING_REQUIREMENTS = ['random_jackson_pivot', 'exoplanet'];
 
   /**
    * @covers ::getRequirements
@@ -41,7 +41,7 @@ public static function getRequirementsProvider() {
         ['requirements' => static::MISSING_REQUIREMENTS[0]],
       ],
       [
-        'requirements: random_jackson_pivot. requirements: 51_Eridani_b.',
+        'requirements: random_jackson_pivot. requirements: exoplanet.',
         'Multiple Requirements',
         ['requirements' => static::MISSING_REQUIREMENTS],
       ],
diff --git a/core/modules/node/tests/src/Functional/Rest/NodeResourceTestBase.php b/core/modules/node/tests/src/Functional/Rest/NodeResourceTestBase.php
index 1832ca50931afac47f09bac2a816b7ebfb4a9a12..503d44d8ef827502968a4ca2e371e3697dcade2d 100644
--- a/core/modules/node/tests/src/Functional/Rest/NodeResourceTestBase.php
+++ b/core/modules/node/tests/src/Functional/Rest/NodeResourceTestBase.php
@@ -205,7 +205,7 @@ protected function getNormalizedPostEntity() {
       ],
       'title' => [
         [
-          'value' => 'Dramallama',
+          'value' => 'Drama llama',
         ],
       ],
     ];
diff --git a/core/modules/path_alias/tests/src/Unit/PathProcessor/AliasPathProcessorTest.php b/core/modules/path_alias/tests/src/Unit/PathProcessor/AliasPathProcessorTest.php
index abbf8b5d7f970c3b07bf03c265410e8a2d722faa..f82bd3ab89301808941653805e82a5d384f0c0fd 100644
--- a/core/modules/path_alias/tests/src/Unit/PathProcessor/AliasPathProcessorTest.php
+++ b/core/modules/path_alias/tests/src/Unit/PathProcessor/AliasPathProcessorTest.php
@@ -48,12 +48,12 @@ public function testProcessInbound() {
     $this->aliasManager->expects($this->exactly(2))
       ->method('getPathByAlias')
       ->willReturnMap([
-        ['urlalias', NULL, 'internal-url'],
+        ['url-alias', NULL, 'internal-url'],
         ['url', NULL, 'url'],
       ]);
 
-    $request = Request::create('/urlalias');
-    $this->assertEquals('internal-url', $this->pathProcessor->processInbound('urlalias', $request));
+    $request = Request::create('/url-alias');
+    $this->assertEquals('internal-url', $this->pathProcessor->processInbound('url-alias', $request));
     $request = Request::create('/url');
     $this->assertEquals('url', $this->pathProcessor->processInbound('url', $request));
   }
@@ -67,7 +67,7 @@ public function testProcessOutbound($path, array $options, $expected_path) {
     $this->aliasManager->expects($this->any())
       ->method('getAliasByPath')
       ->willReturnMap([
-        ['internal-url', NULL, 'urlalias'],
+        ['internal-url', NULL, 'url-alias'],
         ['url', NULL, 'url'],
       ]);
 
@@ -83,7 +83,7 @@ public function testProcessOutbound($path, array $options, $expected_path) {
    */
   public function providerTestProcessOutbound() {
     return [
-      ['internal-url', [], 'urlalias'],
+      ['internal-url', [], 'url-alias'],
       ['internal-url', ['alias' => TRUE], 'internal-url'],
       ['url', [], 'url'],
     ];
diff --git a/core/modules/rest/tests/src/Functional/FileUploadResourceTestBase.php b/core/modules/rest/tests/src/Functional/FileUploadResourceTestBase.php
index 56bceaf366bf42b9abcb76bfb66b11b3c815fb00..5e1afccfcdd3c945b5d8cc0df93ca0ca034a32db 100644
--- a/core/modules/rest/tests/src/Functional/FileUploadResourceTestBase.php
+++ b/core/modules/rest/tests/src/Functional/FileUploadResourceTestBase.php
@@ -237,7 +237,7 @@ protected function getNormalizedPostEntity() {
       ],
       'name' => [
         [
-          'value' => 'Dramallama',
+          'value' => 'Drama llama',
         ],
       ],
       'field_rest_file_test' => [
diff --git a/core/modules/search/tests/src/Functional/SearchCommentTest.php b/core/modules/search/tests/src/Functional/SearchCommentTest.php
index dd61a161a70b0b5ea9fb7b32f494182bca5af8b2..b605f5465edc35ee6251f8277df49b1eb2fc4312 100644
--- a/core/modules/search/tests/src/Functional/SearchCommentTest.php
+++ b/core/modules/search/tests/src/Functional/SearchCommentTest.php
@@ -141,8 +141,8 @@ public function testSearchResultsComment() {
     // script tag nearby a keyword in the comment body. Use the 'FULL HTML' text
     // format so the script tag stored.
     $edit_comment2 = [];
-    $edit_comment2['subject[0][value]'] = "<script>alert('subjectkeyword');</script>";
-    $edit_comment2['comment_body[0][value]'] = "nearbykeyword<script>alert('somethinggeneric');</script>";
+    $edit_comment2['subject[0][value]'] = "<script>alert('subject_keyword');</script>";
+    $edit_comment2['comment_body[0][value]'] = "nearby-keyword<script>alert('something generic');</script>";
     $edit_comment2['comment_body[0][format]'] = $full_html_format_id;
     $this->drupalGet('comment/reply/node/' . $node->id() . '/comment');
     $this->submitForm($edit_comment2, 'Save');
@@ -151,7 +151,7 @@ public function testSearchResultsComment() {
     // body. Use the 'FULL HTML' text format so the script tag is stored.
     $edit_comment3 = [];
     $edit_comment3['subject[0][value]'] = 'a subject';
-    $edit_comment3['comment_body[0][value]'] = "<script>alert('insidekeyword');</script>";
+    $edit_comment3['comment_body[0][value]'] = "<script>alert('inside-keyword');</script>";
     $edit_comment3['comment_body[0][format]'] = $full_html_format_id;
     $this->drupalGet('comment/reply/node/' . $node->id() . '/comment');
     $this->submitForm($edit_comment3, 'Save');
@@ -186,30 +186,30 @@ public function testSearchResultsComment() {
 
     // Search for the evil script comment subject.
     $edit = [
-      'keys' => 'subjectkeyword',
+      'keys' => 'subject_keyword',
     ];
     $this->drupalGet('search/node');
     $this->submitForm($edit, 'Search');
 
     // Verify the evil comment subject is escaped in search results.
-    $this->assertSession()->responseContains('&lt;script&gt;alert(&#039;<strong>subjectkeyword</strong>&#039;);');
+    $this->assertSession()->responseContains('&lt;script&gt;alert(&#039;<strong>subject_keyword</strong>&#039;);');
     $this->assertSession()->responseNotContains('<script>');
 
     // Search for the keyword near the evil script tag in the comment body.
     $edit = [
-      'keys' => 'nearbykeyword',
+      'keys' => 'nearby-keyword',
     ];
     $this->drupalGet('search/node');
     $this->submitForm($edit, 'Search');
 
     // Verify that nearby script tag in the evil comment body is stripped from
     // search results.
-    $this->assertSession()->responseContains('<strong>nearbykeyword</strong>');
+    $this->assertSession()->responseContains('<strong>nearby-keyword</strong>');
     $this->assertSession()->responseNotContains('<script>');
 
     // Search for contents inside the evil script tag in the comment body.
     $edit = [
-      'keys' => 'insidekeyword',
+      'keys' => 'inside-keyword',
     ];
     $this->drupalGet('search/node');
     $this->submitForm($edit, 'Search');
diff --git a/core/modules/search/tests/src/Functional/SearchRankingTest.php b/core/modules/search/tests/src/Functional/SearchRankingTest.php
index 341809fd543e6480a536b453738ec5658c9aa837..7866af22e94cb45202b2f8ed9102afa076148a05 100644
--- a/core/modules/search/tests/src/Functional/SearchRankingTest.php
+++ b/core/modules/search/tests/src/Functional/SearchRankingTest.php
@@ -217,7 +217,7 @@ public function testHTMLRankings() {
     $full_html_format->save();
 
     // Test HTML tags with different weights.
-    $sorted_tags = ['h1', 'h2', 'h3', 'h4', 'a', 'h5', 'h6', 'notag'];
+    $sorted_tags = ['h1', 'h2', 'h3', 'h4', 'a', 'h5', 'h6', 'NoTag'];
     $shuffled_tags = $sorted_tags;
 
     // Shuffle tags to ensure HTML tags are ranked properly.
@@ -233,7 +233,7 @@ public function testHTMLRankings() {
           $settings['body'] = [['value' => Link::fromTextAndUrl('Drupal Rocks', Url::fromRoute('<front>'))->toString(), 'format' => 'full_html']];
           break;
 
-        case 'notag':
+        case 'NoTag':
           $settings['body'] = [['value' => 'Drupal Rocks']];
           break;
 
@@ -256,7 +256,7 @@ public function testHTMLRankings() {
     // Test the ranking of each tag.
     foreach ($sorted_tags as $tag_rank => $tag) {
       // Assert the results.
-      if ($tag == 'notag') {
+      if ($tag == 'NoTag') {
         $this->assertEquals($nodes[$tag]->id(), $set[$tag_rank]['node']->id(), 'Search tag ranking for plain text order.');
       }
       else {
diff --git a/core/modules/system/tests/modules/entity_test/tests/src/Functional/Rest/EntityTestMapFieldResourceTestBase.php b/core/modules/system/tests/modules/entity_test/tests/src/Functional/Rest/EntityTestMapFieldResourceTestBase.php
index 658785ba8464aca18875a5f0d5ebb52e1cb07f91..4d236ebebc2afa7cb3e2045552a04fe309d5dddc 100644
--- a/core/modules/system/tests/modules/entity_test/tests/src/Functional/Rest/EntityTestMapFieldResourceTestBase.php
+++ b/core/modules/system/tests/modules/entity_test/tests/src/Functional/Rest/EntityTestMapFieldResourceTestBase.php
@@ -120,7 +120,7 @@ protected function getNormalizedPostEntity() {
     return [
       'name' => [
         [
-          'value' => 'Dramallama',
+          'value' => 'Drama llama',
         ],
       ],
       'data' => [
diff --git a/core/modules/system/tests/modules/entity_test/tests/src/Functional/Rest/EntityTestResourceTestBase.php b/core/modules/system/tests/modules/entity_test/tests/src/Functional/Rest/EntityTestResourceTestBase.php
index 7985a3244c917f85575488b1419cd7fab162a803..e6a1c6a10191a7447d5041385e756eb56b11ad46 100644
--- a/core/modules/system/tests/modules/entity_test/tests/src/Functional/Rest/EntityTestResourceTestBase.php
+++ b/core/modules/system/tests/modules/entity_test/tests/src/Functional/Rest/EntityTestResourceTestBase.php
@@ -156,7 +156,7 @@ protected function getNormalizedPostEntity() {
       ],
       'name' => [
         [
-          'value' => 'Dramallama',
+          'value' => 'Drama llama',
         ],
       ],
     ];
diff --git a/core/modules/system/tests/src/Kernel/Common/UrlTest.php b/core/modules/system/tests/src/Kernel/Common/UrlTest.php
index f40ae58d73afe3618f44330a099002af3501b8e6..a9512b5b3173bf929bbb632cbe8884c8ae5eaeee 100644
--- a/core/modules/system/tests/src/Kernel/Common/UrlTest.php
+++ b/core/modules/system/tests/src/Kernel/Common/UrlTest.php
@@ -30,7 +30,7 @@ public function testLinkXSS() {
     // Test link generator.
     $text = $this->randomMachineName();
     $path = "<SCRIPT>alert('XSS')</SCRIPT>";
-    $encoded_path = "3CSCRIPT%3Ealert%28%27XSS%27%29%3C/SCRIPT%3E";
+    $encoded_path = "%3CSCRIPT%3Ealert%28%27XSS%27%29%3C/SCRIPT%3E";
 
     $link = Link::fromTextAndUrl($text, Url::fromUserInput('/' . $path))->toString();
     $this->assertStringContainsString($encoded_path, $link, new FormattableMarkup('XSS attack @path was filtered by \Drupal\Core\Utility\LinkGeneratorInterface::generate().', ['@path' => $path]));
diff --git a/core/modules/taxonomy/tests/src/Functional/Rest/TermResourceTestBase.php b/core/modules/taxonomy/tests/src/Functional/Rest/TermResourceTestBase.php
index 76ddf9026c977da92f7071d90aca0d13ed14c770..e2e728f0f2d70036c5d364d2abc0bce67ba9a3c2 100644
--- a/core/modules/taxonomy/tests/src/Functional/Rest/TermResourceTestBase.php
+++ b/core/modules/taxonomy/tests/src/Functional/Rest/TermResourceTestBase.php
@@ -241,12 +241,12 @@ protected function getNormalizedPostEntity() {
       ],
       'name' => [
         [
-          'value' => 'Dramallama',
+          'value' => 'Drama llama',
         ],
       ],
       'description' => [
         [
-          'value' => 'Dramallamas are the coolest camelids.',
+          'value' => 'Drama llamas are the coolest camelids.',
           'format' => NULL,
         ],
       ],
diff --git a/core/modules/text/tests/src/Unit/Plugin/migrate/field/d6/TextFieldTest.php b/core/modules/text/tests/src/Unit/Plugin/migrate/field/d6/TextFieldTest.php
index 9614da3ddaee0c87505ad1da202cab46245bb973..04e63780d5ad061af2b3c53f5976c2f815190f95 100644
--- a/core/modules/text/tests/src/Unit/Plugin/migrate/field/d6/TextFieldTest.php
+++ b/core/modules/text/tests/src/Unit/Plugin/migrate/field/d6/TextFieldTest.php
@@ -103,7 +103,7 @@ public function testBooleanTextExplicitValueProcessPipeline() {
     $info = [
       'widget_type' => 'optionwidgets_onoff',
       'global_settings' => [
-        'allowed_values' => "foo|Foo\nbaz|Baz",
+        'allowed_values' => "foo|Foo\nBaz|Baz",
       ],
     ];
     $this->plugin->defineValueProcessPipeline($this->migration, 'field', $info);
@@ -114,7 +114,7 @@ public function testBooleanTextExplicitValueProcessPipeline() {
         'source' => 'value',
         'default_value' => 0,
         'map' => [
-          'baz' => 1,
+          'Baz' => 1,
         ],
       ],
     ];
diff --git a/core/modules/user/tests/src/Functional/Rest/UserResourceTestBase.php b/core/modules/user/tests/src/Functional/Rest/UserResourceTestBase.php
index 88d6d7532db1abeb06e27da55fbad179b35d3f47..a15a65227c747dffcd2708d877d5b47d4a85be6d 100644
--- a/core/modules/user/tests/src/Functional/Rest/UserResourceTestBase.php
+++ b/core/modules/user/tests/src/Functional/Rest/UserResourceTestBase.php
@@ -136,7 +136,7 @@ protected function getNormalizedPostEntity() {
     return [
       'name' => [
         [
-          'value' => 'Dramallama',
+          'value' => 'Drama llama',
         ],
       ],
     ];
diff --git a/core/modules/user/tests/src/Functional/UserLoginHttpTest.php b/core/modules/user/tests/src/Functional/UserLoginHttpTest.php
index 8776e68b7098279a8c7787f519142ac721197a4d..3e018ae11c5075d120541e2d34f2879041d9e352 100644
--- a/core/modules/user/tests/src/Functional/UserLoginHttpTest.php
+++ b/core/modules/user/tests/src/Functional/UserLoginHttpTest.php
@@ -534,7 +534,7 @@ protected function doTestPasswordReset($format, $account) {
     $response = $this->passwordRequest([], $format);
     $this->assertHttpResponseWithMessage($response, 400, 'Missing credentials.name or credentials.mail', $format);
 
-    $response = $this->passwordRequest(['name' => 'dramallama'], $format);
+    $response = $this->passwordRequest(['name' => 'drama llama'], $format);
     $this->assertEquals(200, $response->getStatusCode());
 
     $response = $this->passwordRequest(['mail' => 'llama@drupal.org'], $format);
diff --git a/core/modules/user/tests/src/Functional/UserRegistrationRestTest.php b/core/modules/user/tests/src/Functional/UserRegistrationRestTest.php
index 5bd6e44e928fcd0dc3cb621c6eaeff38c5286ddd..0cb3f734448713dabd528274432e7f0da082316f 100644
--- a/core/modules/user/tests/src/Functional/UserRegistrationRestTest.php
+++ b/core/modules/user/tests/src/Functional/UserRegistrationRestTest.php
@@ -85,14 +85,14 @@ public function testRegisterUser() {
     $this->assertEquals(0, $email_count);
 
     // Attempt to register without sending a password.
-    $response = $this->registerRequest('Rick.Deckard', FALSE);
+    $response = $this->registerRequest('PhilipK.Dick', FALSE);
     $this->assertResourceErrorResponse(422, "No password provided.", $response);
 
     // Attempt to register with a password when email verification is on.
     $config->set('register', UserInterface::REGISTER_VISITORS);
     $config->set('verify_mail', 1);
     $config->save();
-    $response = $this->registerRequest('Estraven');
+    $response = $this->registerRequest('UrsulaK.LeGuin');
     $this->assertResourceErrorResponse(422, 'A Password cannot be specified. It will be generated on login.', $response);
 
     // Allow visitors to register with email verification.
@@ -123,14 +123,14 @@ public function testRegisterUser() {
     $config->set('register', UserInterface::REGISTER_VISITORS_ADMINISTRATIVE_APPROVAL);
     $config->set('verify_mail', 1);
     $config->save();
-    $name = 'Bob.Arctor';
+    $name = 'PhilipK.Dick';
     $user = $this->registerUser($name, FALSE);
     $this->resetAll();
     $this->assertEmpty($user->getPassword());
     $this->assertTrue($user->isBlocked());
 
     $this->assertMailString('body', 'Your application for an account is', 2);
-    $this->assertMailString('body', 'Bob.Arctor has applied for an account', 2);
+    $this->assertMailString('body', 'PhilipK.Dick has applied for an account', 2);
 
     // Verify that an authenticated user cannot register a new user, despite
     // being granted permission to do so because only anonymous users can
diff --git a/core/modules/workspaces/tests/src/Functional/WorkspaceSwitcherTest.php b/core/modules/workspaces/tests/src/Functional/WorkspaceSwitcherTest.php
index b6419a83213ec8584661b2c51be746d64c3bd756..2299d4986c65048cd520607096dfd2c3e101a933 100644
--- a/core/modules/workspaces/tests/src/Functional/WorkspaceSwitcherTest.php
+++ b/core/modules/workspaces/tests/src/Functional/WorkspaceSwitcherTest.php
@@ -72,16 +72,16 @@ public function testSwitchingWorkspaces() {
   public function testQueryParameterNegotiator() {
     $web_assert = $this->assertSession();
     // Initially the default workspace should be active.
-    $web_assert->elementContains('css', '#block-workspaceswitcher', 'None');
+    $web_assert->elementContains('css', '#block-workspace-switcher', 'None');
 
     // When adding a query parameter the workspace will be switched.
     $current_user_url = \Drupal::currentUser()->getAccount()->toUrl();
     $this->drupalGet($current_user_url, ['query' => ['workspace' => 'stage']]);
-    $web_assert->elementContains('css', '#block-workspaceswitcher', 'Stage');
+    $web_assert->elementContains('css', '#block-workspace-switcher', 'Stage');
 
     // The workspace switching via query parameter should persist.
     $this->drupalGet($current_user_url);
-    $web_assert->elementContains('css', '#block-workspaceswitcher', 'Stage');
+    $web_assert->elementContains('css', '#block-workspace-switcher', 'Stage');
 
     // Check that WorkspaceCacheContext provides the cache context used to
     // support its functionality.
diff --git a/core/modules/workspaces/tests/src/Functional/WorkspaceTestUtilities.php b/core/modules/workspaces/tests/src/Functional/WorkspaceTestUtilities.php
index 09b16c23ece05b12048ee724ceeaa8990c0a3c6a..217d896082ca5c0897b4dad742b986c44ce1d7b6 100644
--- a/core/modules/workspaces/tests/src/Functional/WorkspaceTestUtilities.php
+++ b/core/modules/workspaces/tests/src/Functional/WorkspaceTestUtilities.php
@@ -78,7 +78,7 @@ protected function createWorkspaceThroughUi($label, $id, $parent = '_none') {
   protected function setupWorkspaceSwitcherBlock() {
     // Add the block to the sidebar.
     $this->placeBlock('workspace_switcher', [
-      'id' => 'workspaceswitcher',
+      'id' => 'workspace_switcher',
       'region' => 'sidebar_first',
       'label' => 'Workspace switcher',
     ]);
diff --git a/core/modules/field_ui/tests/src/Functional/EntityDisplayModeTest.php b/core/modules/field_ui/tests/src/Functional/EntityDisplayModeTest.php
index 5343cc444c736f725b93a08523056c497695b315..130f559305e523d5e81dad5d9e8c8c9aa596fee5 100644
--- a/core/modules/field_ui/tests/src/Functional/EntityDisplayModeTest.php
+++ b/core/modules/field_ui/tests/src/Functional/EntityDisplayModeTest.php
@@ -186,24 +186,24 @@ public function testAlphabeticalDisplaySettings() {
       $pos = $new_pos;
     }
     // Now that we have verified the original display order, we can change the
     // label for one of the view modes. If we rename "Teaser" to "Breezer", it
     // should appear as the first of the listed view modes:
     // Set new values and enable test plugins.
     $edit = [
-      'label' => 'Breezer',
+      'label' => 'Breezier',
     ];
     $this->drupalGet('admin/structure/display-modes/view/manage/node.teaser');
     $this->submitForm($edit, 'Save');
-    $this->assertSession()->pageTextContains('Saved the Breezer view mode.');
+    $this->assertSession()->pageTextContains('Saved the Breezier view mode.');
 
     // Re-open the display settings for the article content type and verify
     // that changing "Teaser" to "Breezer" makes it appear before "Full
     // content".
     $this->drupalGet('admin/structure/types/manage/article/display');
     $page_text = $this->getTextContent();
     $start = strpos($page_text, 'view modes');
     $pos = $start;
-    $list = ['Breezer', 'Full content'];
+    $list = ['Breezier', 'Full content'];
     // Verify that the order of the view modes is correct on the page.
     foreach ($list as $name) {
       $new_pos = strpos($page_text, $name, $start);
@@ -186,24 +186,24 @@ public function testAlphabeticalDisplaySettings() {
     }
     // Now that we have verified the original display order, we can change the
-    // label for one of the view modes. If we rename "Teaser" to "Breezer", it
+    // label for one of the view modes. If we rename "Teaser" to "Breezier", it
     // should appear as the first of the listed view modes:
     // Set new values and enable test plugins.
@@ -186,24 +186,24 @@ public function testAlphabeticalDisplaySettings() {
 
     // Re-open the display settings for the article content type and verify
-    // that changing "Teaser" to "Breezer" makes it appear before "Full
+    // that changing "Teaser" to "Breezier" makes it appear before "Full
     // content".
     $this->drupalGet('admin/structure/types/manage/article/display');